"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BullQueueHealthIndicator = void 0;
const bull_1 = require("@nestjs/bull");
const common_1 = require("@nestjs/common");
const core_1 = require("@nestjs/core");
const terminus_1 = require("@nestjs/terminus");
let BullQueueHealthIndicator = class BullQueueHealthIndicator extends terminus_1.HealthIndicator {
    constructor(moduleRef) {
        super();
        this.moduleRef = moduleRef;
    }
    async isHealthy(queues) {
        const promiseResults = await this.checkQueuesReady(queues);
        const errorResults = this.filterErrors(promiseResults);
        if (errorResults.length) {
            throw new terminus_1.HealthCheckError('Bull queue failed', this.getStatus('bull', false, { errors: errorResults }));
        }
        return this.getStatus('bull', true);
    }
    filterErrors(promiseResults) {
        const errorResults = [];
        for (const promiseResult of promiseResults) {
            if (promiseResult.status === 'rejected') {
                if (promiseResult.reason instanceof Error) {
                    errorResults.push(promiseResult.reason.message);
                }
                else {
                    errorResults.push(promiseResult.reason);
                }
            }
        }
        return errorResults;
    }
    async checkQueuesReady(queues) {
        const promises = queues.map(async (name) => {
            const queueToken = this.moduleRef.get((0, bull_1.getQueueToken)(name), { strict: false });
            if (queueToken.isReady) {
                const queue = await queueToken.isReady();
                const isEveryClientReady = queue.clients.every((client) => client.status === 'ready');
                if (!isEveryClientReady) {
                    throw new Error(`${name} - some redis clients are not ready`);
                }
                return true;
            }
            throw new Error(`${name} is not a bull queue`);
        });
        return Promise.allSettled(promises);
    }
};
BullQueueHealthIndicator = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [core_1.ModuleRef])
], BullQueueHealthIndicator);
exports.BullQueueHealthIndicator = BullQueueHealthIndicator;
//# sourceMappingURL=bull-queue.health.js.map